Privacy Policy
==============

RecaptureDocs provides a service of facilitating the assignment of
document retypists to clients in need of the service. In doing so,
RecaptureDocs must collect certain information to facilitate the
transaction.

Data Collected
--------------

RecaptureDocs attempts to collect only a minimum amount of personal
information in order to complete the transaction. A client can utilize
the system without providing any identifying information. Some network-
essential information (such as IP address) may be stored temporarily
for diagnostic purposes.

All payments and personal information for the payment system is
maintained by Amazon Payment Systems and is not stored by RecaptureDocs.

Resale of Information
---------------------

RecaptureDocs will not share client data with any other entity except
for the sole purpose of conducting the transaction.

Retention and Removal
---------------------

Currently, there is no formal schedule for archival or deletion of
client data. RecaptureDocs will remove completed data on request and
will not retain client data for longer than one (1) year after the last
date of use.
